/*
 * TrainRIprops.java
 * Copyright (c) 2004, KTH NADA.
 *
 * This file is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this software; see the file COPYING.  If not, see
 * http://opensource.org/licenses/gpl-license.php
 *
 * Martin Hassel, 2004-Oct-06
 * http://www.nada.kth.se/~xmartin/
 */

import java.io.File;
import java.io.FileInputStream;
import java.io.OutputStreamWriter;
import java.util.Properties;

import moj.ri.RIprops;

/**
 * @author  Martin Hassel
 * @version 2006-Oct-18
 */
public class TrainRIprops extends RIprops {
    // Default values for the properties for Trainer
    private static final String _save_compressed = "True";
    private static final String _restrict_extension = ".txt";
    private static final String _discourse_marker = "";
    private static final String _strip_html = "False";
    private static final String _granska = "off";
    private static final String _save_preprocessed_text = "False";
    private static final String _vocabulary_file = "";
    private static final String _start_new_index = "False";
    private static final String _number_of_threads = Runtime.getRuntime().availableProcessors() + "";
    private static final String _retries = "5";
    private static final String _log = "false";
    private static final String _lower_case = "true";
    private static final String _purge_on_save = "false";

    // Actual values
    public boolean saveCompressed;
    public String restrictExtension;
    public String discourseMarker;
    public boolean stripHTML;
    public String granska;
    public boolean savePreprocessedText;
    public String vocabularyFile;
    public boolean startNewIndex;
    public int numberOfThreads;
    public int retries;
    public boolean log;
    public boolean lowercase;
    public boolean purge_on_save;

    public TrainRIprops(String propsfile) {
    	super(propsfile);
    	try {
    		// Load and set properties for the Trainer
    		Properties props = new Properties();
			if(new File(propsfile).exists())
				props.load(new FileInputStream(propsfile));
    		saveCompressed = Boolean.valueOf(props.getProperty("save_compressed",_save_compressed)).booleanValue();
    		restrictExtension = props.getProperty("restrict_extension",_restrict_extension);
    		discourseMarker = props.getProperty("discourse_marker",_discourse_marker);
    		stripHTML = Boolean.valueOf(props.getProperty("strip_html",_strip_html)).booleanValue();
    		granska = props.getProperty("granska",_granska);
    		savePreprocessedText = Boolean.valueOf(props.getProperty("save_preprocessed_text",_save_preprocessed_text)).booleanValue();
    		vocabularyFile = props.getProperty("vocabulary_file",_vocabulary_file);
			startNewIndex = Boolean.valueOf(props.getProperty("start_new_index",_start_new_index)).booleanValue();
			numberOfThreads = Integer.valueOf(props.getProperty("number_of_threads",_number_of_threads)).intValue();
			retries = Integer.valueOf(props.getProperty("retries",_retries)).intValue();
			log = Boolean.valueOf(props.getProperty("log",_log)).booleanValue();
			lowercase = Boolean.valueOf(props.getProperty("lower_case",_lower_case)).booleanValue();
			purge_on_save = Boolean.valueOf(props.getProperty("purge_on_save",_purge_on_save)).booleanValue();
    	} catch(Exception ex) {
    		ex.printStackTrace();
    	}
    }

    public void writeProperties(OutputStreamWriter osw) {
		super.writeProperties(osw);
    	try {
    		osw.write("\n");
    		osw.flush();
    	} catch(Exception ex) {
    		ex.printStackTrace();
    	}
    }
}
