package moj.lang.statserv;

import java.io.Reader;

/**
 * StatServRequest in an abstract class that stipulates what fields and methods 
 * a StatServ request module at least should supply and implement.
 *
 * @author  Martin Hassel
 * @version 2006-Dec-13
 */
public abstract class StatServRequest {
	public final String docset;
	public final String classname;
	public final boolean localstats;
	public final boolean referencestats;
	public final boolean addstats;

	/**
	 * Creates new <code>StatServRequest</code> and fills mandatory fields.
	 * @param classname name of the <code>StatServRequest</code> module
	 * @param docset the document set statistics is requested for
	 * @param localstats is local statistics requested?
	 * @param referencestats is reference statistics requested?
	 * @param addstats is statistics to be added to the document set?
	 */
	protected StatServRequest(String classname, String docset, boolean localstats, boolean referencestats, boolean addstats) {
		this.docset = docset;
		this.classname = classname;
		this.localstats = localstats;
		this.referencestats = referencestats;
		this.addstats = addstats;
	}

	/**
	 * Returns the XML that constitutes the modules part in a 
	 * <code>StatServConnection</code> request.  
	 * @return XML representing the modules part in a request
	 */
	public abstract String requestXML();

	/**
	 * Parses the XML passed via the <code>Reader</code> and fills the modules 
	 * data structures. 
	 * @param xmlReader <code>Reader</code> wrapping the XML response from a 
	 * <code>StatServConnection</code> request.
	 * @return <code>true</code> on success, else <code>false</code>
	 */
	public abstract boolean parse(Reader xmlReader);
}
