/*
 * RIprops.java
 * Copyright (c) 2004, KTH NADA.
 *
 * This file is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this software; see the file COPYING.  If not, see
 * http://opensource.org/licenses/gpl-license.php
 *
 * Martin Hassel, 2004-Oct-06
 * http://www.nada.kth.se/~xmartin/
 */

package moj.ri;

import java.io.File;
import java.io.FileInputStream;
import java.io.OutputStreamWriter;
import java.util.Properties;

/**
 * @author  Martin Hassel
 * @version 2006-Sep-26
 */
public class RIprops {
	// Default values for the properties for RandomIndex
	private static final String _dimensionality = "1800";
	private static final String _random_degree  = "8";
	private static final String _seed = "710225";
	private static final String _left_window_size  = "4";
	private static final String _right_window_size = "4";
	private static final String _weighting_scheme = "moj.ri.weighting.MangesWS";
	private static final String _document_labels = "False";
	private static final String _unary_labels = "False";

	public int dimensionality;
	public int randomDegree;
	public int seed;
	public int leftWindowSize;
	public int rightWindowSize;
	public String weightingScheme;
	public boolean documentLabels;
	public boolean unaryLabels;

	public RIprops(String propsfile){
		try {
			// Load and set properties for the RandomIndex
			Properties props = new Properties();
			if(new File(propsfile).exists())
				props.load(new FileInputStream(propsfile));
			dimensionality = Integer.parseInt(props.getProperty("dimensionality",_dimensionality));
			randomDegree  = Integer.parseInt(props.getProperty("random_degree",_random_degree));
			seed = Integer.parseInt(props.getProperty("seed",_seed));
			leftWindowSize  = Integer.parseInt(props.getProperty("left_window_size",_left_window_size));
			rightWindowSize = Integer.parseInt(props.getProperty("right_window_size",_right_window_size));
			weightingScheme = props.getProperty("weighting_scheme",_weighting_scheme);
			documentLabels = Boolean.valueOf(props.getProperty("document_labels",_document_labels)).booleanValue();
			unaryLabels = Boolean.valueOf(props.getProperty("unary_labels",_unary_labels)).booleanValue();
		} catch(Exception ex) {
			ex.printStackTrace();
		}
	}

	public void writeProperties(OutputStreamWriter osw){
		try {
			osw.write("dimensionality = " + dimensionality + "\n");
			osw.write("random_degree = "  + randomDegree + "\n");
			osw.write("seed = " + seed + "\n");
			osw.write("left_window_size = "  + leftWindowSize + "\n");
			osw.write("right_window_size = " + rightWindowSize + "\n");
			osw.write("weighting_scheme = " + weightingScheme + "\n");
			osw.write("document_labels = " + documentLabels + "\n");
			osw.write("unary_labels = " + unaryLabels + "\n");
			osw.flush();
		} catch(Exception ex) {
			ex.printStackTrace();
		}
	}
}
