/*
 * Created on 2005-dec-02
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package moj.util;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStreamReader;
import java.nio.charset.Charset;

import cpdetector.io.ASCIIDetector;
import cpdetector.io.CodepageDetectorProxy;
import cpdetector.io.JChardetFacade;
import cpdetector.io.ParsingDetector;

/**
 * A small utility class that contains methods for handling files.
 * 
 * @author Martin Hassel
 * @version 2006-Dec-08
 */
public class FileTools {
	// CodepageDetectorProxy is a singleton
	private static CodepageDetectorProxy cpdet = null;

	/**
	 * Reads a file into a <code>String</code> using cpdetector for code page detection.
	 * 
	 * @param filename name of the file to read into a <code>String</code>
	 * @return a <code>String</code> containing the given file (line breaks preserved)
	 */
	public static String readFile2String(String filename) {
		String file = "";
		if(cpdet == null) {
			// Set codepage detection first time the method is called
			cpdet = CodepageDetectorProxy.getInstance();
			cpdet.add(new ParsingDetector());		  // What does the document claim to be?
			cpdet.add(JChardetFacade.getInstance());  // JChardetFacade is a singleton
			cpdet.add(ASCIIDetector.getInstance());	  // Fallback, also singleton
		}
		try {
			file = readFile2String(filename, cpdet.detectCodepage(new File(filename).toURL()));
		} catch(IOException ioe) {
			ioe.printStackTrace();
		}
		return(file);
	}

	/**
	 * Reads a file into a <code>String</code> using the provided charset.
	 * 
	 * @param filename name of the file to read into a <code>String</code>
	 * @param cs the <code>Charset</code> to use when reading the file
	 * @return a <code>String</code> containing the given file (line breaks preserved)
	 */
	public static String readFile2String(String filename, Charset cs) {
		// Read current file into a StringBuffer
		StringBuffer doc = new StringBuffer();
		try {
			// We need to specify charset/codepage
			BufferedReader txtbr = new BufferedReader(
					new InputStreamReader(new FileInputStream(filename), cs));
			// Append lines to form one "single" line (with line breaks)
			String line = null;
			while((line = txtbr.readLine()) != null)
				doc.append(line + "\n");
			txtbr.close();
		} catch(FileNotFoundException fnfe) {
			System.err.println("Error: File '" + filename + "' not found.");
		} catch(IOException ioe) {
			ioe.printStackTrace();
		}
		return(doc.toString());
	}
}
