/*
 * ReverseEntryValueComparator.java
 * No copyright (generic solution)
 *
 * This file is part of SweSum^2 (see http://swesum.nada.kth.se/),
 * and is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this software; see the file COPYING.  If not, see
 * http://opensource.org/licenses/gpl-license.php
 *
 */

package moj.util;

import java.util.Comparator;
import java.util.Map;

/**
 * Comparator that compares values. Note that it compares the keys as well as
 * the values. This is necessary to be consistent with Map.Entry.equals() and
 * to ensure that our entrySet behaves like a Set.
 */
public class ReverseEntryValueComparator implements Comparator<Map.Entry<String,Float>> {

    /**
     * Compares values in reverse order. Note that it compares the keys as well as the values. 
     * This is necessary to be consistent with Map.Entry.equals() and to 
     * ensure that our entrySet behaves like a Set.
     * @param e1 <code>Map.Entry&lt;String,Float&gt;</code> that is to be compared to <code>e2</code>.
     * @param e2 <code>Map.Entry&lt;String,Float&gt;</code> that is to be compared to <code>e1</code>.
     * @return the difference between <code>e1</code> and <code>e2</code>.
     */    
    public int compare(Map.Entry<String,Float> e1, Map.Entry<String,Float> e2) {
        int diff = e1.getValue().compareTo(e2.getValue());
        if (diff == 0) {
            diff = e1.getKey().compareTo(e2.getKey());
        }
        return -diff;
    }
}
